summaryrefslogtreecommitdiff
path: root/src/being.h
diff options
context:
space:
mode:
authorEugenio Favalli <elvenprogrammer@gmail.com>2005-01-15 14:15:50 +0000
committerEugenio Favalli <elvenprogrammer@gmail.com>2005-01-15 14:15:50 +0000
commit9171b9739dfb8a1ca0bf963c5041d0a801e4aa90 (patch)
treea7e4514fb14b0c166ec052df1887b4963c51574b /src/being.h
parent806dd2ec3cdb39c8ae528b65f93984ed66496709 (diff)
downloadmana-client-9171b9739dfb8a1ca0bf963c5041d0a801e4aa90.tar.gz
mana-client-9171b9739dfb8a1ca0bf963c5041d0a801e4aa90.tar.bz2
mana-client-9171b9739dfb8a1ca0bf963c5041d0a801e4aa90.tar.xz
mana-client-9171b9739dfb8a1ca0bf963c5041d0a801e4aa90.zip
Being struct/class switch
Diffstat (limited to 'src/being.h')
-rw-r--r--src/being.h41
1 files changed, 8 insertions, 33 deletions
diff --git a/src/being.h b/src/being.h
index cc7b3973..ec58b986 100644
--- a/src/being.h
+++ b/src/being.h
@@ -67,41 +67,16 @@ class Being {
Being::~Being();
};
-struct NODE {
- /**
- * Constructor.
- */
- NODE();
-
- unsigned int id;
- short job;
- char coordinates[3];
- unsigned char type;
- unsigned char action;
- unsigned char frame;
- PATH_NODE *path;
- char *speech;
- unsigned char speech_time;
- int speech_color;
- short tick_time;
- short speed;
- unsigned char emotion;
- unsigned char emotion_time;
- int text_x, text_y; // temp solution to fix speech position
- short hair_style, hair_color;
- short weapon;
-};
-
/** Removes all beings from the list */
void empty();
-/** Add a node to the list */
-void add_node(NODE *node);
+/** Add a Being to the list */
+void add_node(Being *Being);
-/** Return a specific id node */
-NODE *find_node(unsigned int id);
+/** Return a specific id Being */
+Being *find_node(unsigned int id);
-/** Remove a node */
+/** Remove a Being */
void remove_node(unsigned int id);
PATH_NODE *calculate_path(
@@ -118,10 +93,10 @@ unsigned int find_monster(unsigned short x, unsigned short y);
void sort();
/** Remove all path nodes from a being */
-void empty_path(NODE *node);
+void empty_path(Being *Being);
-extern NODE *player_node;
+extern Being *player_node;
-extern std::list<NODE*> beings;
+extern std::list<Being*> beings;
#endif